@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -118,21 +118,21 @@ public class MvcUriComponentsBuilderTests {
 
 	@Test
 	public void fromControllerWithCustomBaseUrlViaStaticCall() {
-		UriComponentsBuilder builder = UriComponentsBuilder.fromUriString("http://example.org:9090/base");
+		UriComponentsBuilder builder = UriComponentsBuilder.fromUriString("https://example.org:9090/base");
 		UriComponents uriComponents = fromController(builder, PersonControllerImpl.class).build();
 
-		assertEquals("http://example.org:9090/base/people", uriComponents.toString());
-		assertEquals("http://example.org:9090/base", builder.toUriString());
+		assertEquals("https://example.org:9090/base/people", uriComponents.toString());
+		assertEquals("https://example.org:9090/base", builder.toUriString());
 	}
 
 	@Test
 	public void fromControllerWithCustomBaseUrlViaInstance() {
-		UriComponentsBuilder builder = UriComponentsBuilder.fromUriString("http://example.org:9090/base");
+		UriComponentsBuilder builder = UriComponentsBuilder.fromUriString("https://example.org:9090/base");
 		MvcUriComponentsBuilder mvcBuilder = relativeTo(builder);
 		UriComponents uriComponents = mvcBuilder.withController(PersonControllerImpl.class).build();
 
-		assertEquals("http://example.org:9090/base/people", uriComponents.toString());
-		assertEquals("http://example.org:9090/base", builder.toUriString());
+		assertEquals("https://example.org:9090/base/people", uriComponents.toString());
+		assertEquals("https://example.org:9090/base", builder.toUriString());
 	}
 
 	@Test
@@ -219,23 +219,23 @@ public class MvcUriComponentsBuilderTests {
 
 	@Test
 	public void fromMethodNameWithCustomBaseUrlViaStaticCall() {
-		UriComponentsBuilder builder = UriComponentsBuilder.fromUriString("http://example.org:9090/base");
+		UriComponentsBuilder builder = UriComponentsBuilder.fromUriString("https://example.org:9090/base");
 		UriComponents uriComponents = fromMethodName(builder, ControllerWithMethods.class,
 				"methodWithPathVariable", "1").build();
 
-		assertEquals("http://example.org:9090/base/something/1/foo", uriComponents.toString());
-		assertEquals("http://example.org:9090/base", builder.toUriString());
+		assertEquals("https://example.org:9090/base/something/1/foo", uriComponents.toString());
+		assertEquals("https://example.org:9090/base", builder.toUriString());
 	}
 
 	@Test
 	public void fromMethodNameWithCustomBaseUrlViaInstance() {
-		UriComponentsBuilder builder = UriComponentsBuilder.fromUriString("http://example.org:9090/base");
+		UriComponentsBuilder builder = UriComponentsBuilder.fromUriString("https://example.org:9090/base");
 		MvcUriComponentsBuilder mvcBuilder = relativeTo(builder);
 		UriComponents uriComponents = mvcBuilder.withMethodName(ControllerWithMethods.class,
 				"methodWithPathVariable", "1").build();
 
-		assertEquals("http://example.org:9090/base/something/1/foo", uriComponents.toString());
-		assertEquals("http://example.org:9090/base", builder.toUriString());
+		assertEquals("https://example.org:9090/base/something/1/foo", uriComponents.toString());
+		assertEquals("https://example.org:9090/base", builder.toUriString());
 	}
 
 	@Test  // SPR-14405
@@ -312,21 +312,21 @@ public class MvcUriComponentsBuilderTests {
 
 	@Test
 	public void fromMethodCallWithCustomBaseUrlViaStaticCall() {
-		UriComponentsBuilder builder = UriComponentsBuilder.fromUriString("http://example.org:9090/base");
+		UriComponentsBuilder builder = UriComponentsBuilder.fromUriString("https://example.org:9090/base");
 		UriComponents uriComponents = fromMethodCall(builder, on(ControllerWithMethods.class).myMethod(null)).build();
 
-		assertEquals("http://example.org:9090/base/something/else", uriComponents.toString());
-		assertEquals("http://example.org:9090/base", builder.toUriString());
+		assertEquals("https://example.org:9090/base/something/else", uriComponents.toString());
+		assertEquals("https://example.org:9090/base", builder.toUriString());
 	}
 
 	@Test
 	public void fromMethodCallWithCustomBaseUrlViaInstance() {
-		UriComponentsBuilder builder = UriComponentsBuilder.fromUriString("http://example.org:9090/base");
+		UriComponentsBuilder builder = UriComponentsBuilder.fromUriString("https://example.org:9090/base");
 		MvcUriComponentsBuilder mvcBuilder = relativeTo(builder);
 		UriComponents result = mvcBuilder.withMethodCall(on(ControllerWithMethods.class).myMethod(null)).build();
 
-		assertEquals("http://example.org:9090/base/something/else", result.toString());
-		assertEquals("http://example.org:9090/base", builder.toUriString());
+		assertEquals("https://example.org:9090/base/something/else", result.toString());
+		assertEquals("https://example.org:9090/base", builder.toUriString());
 	}
 
 	@Test  // SPR-16710
@@ -387,10 +387,10 @@ public class MvcUriComponentsBuilderTests {
 
 		this.request.setAttribute(DispatcherServlet.WEB_APPLICATION_CONTEXT_ATTRIBUTE, context);
 
-		UriComponentsBuilder baseUrl = UriComponentsBuilder.fromUriString("http://example.org:9999/base");
+		UriComponentsBuilder baseUrl = UriComponentsBuilder.fromUriString("https://example.org:9999/base");
 		MvcUriComponentsBuilder mvcBuilder = relativeTo(baseUrl);
 		String url = mvcBuilder.withMappingName("PAC#getAddressesForCountry").arg(0, "DE").buildAndExpand(123);
-		assertEquals("http://example.org:9999/base/people/123/addresses/DE", url);
+		assertEquals("https://example.org:9999/base/people/123/addresses/DE", url);
 	}
 
 
